function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/*
 * Copyright (c) 2022 Anton Bagdatyev (Tonix)
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
import { useLayoutEffect } from "react";
import { detectWrapped, isEmpty } from "js-utl";
import useElementSize from "./useElementSize";
import usePrevious from "./usePrevious";
import usePOJOState from "./usePOJOState";
/**
 * Hook detecting wrapped DOM children elements given a ref.
 *
 * @param {Object} ref A ref.
 * @return {Object} An object with the following properties:
 *
 *                      - areWrapped (bool): true if the DOM children elements wrap and are not on the same line
 *                                           (according to their top position);
 *                      - wrapped (Element[]): An array of the wrapped DOM children elements;
 */

export default function useDetectWrappedChildren(ref) {
  var _useElementSize = useElementSize(ref, ["width"]),
      _useElementSize2 = _slicedToArray(_useElementSize, 1),
      width = _useElementSize2[0].width;

  var prevWidth = usePrevious(width);

  var _usePOJOState = usePOJOState(function () {
    return {
      areWrapped: void 0,
      wrapped: []
    };
  }),
      _usePOJOState2 = _slicedToArray(_usePOJOState, 2),
      state = _usePOJOState2[0],
      setState = _usePOJOState2[1];

  useLayoutEffect(function () {
    if (ref.current && ref.current.children && width !== prevWidth) {
      var wrapped = detectWrapped(ref.current.children);
      setState({
        areWrapped: !isEmpty(wrapped),
        wrapped: wrapped
      });
    }
  }, [setState, prevWidth, width, ref]);
  return state;
}
//# sourceMappingURL=useDetectWrappedChildren.js.map