function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import { useRef, useMemo, useEffect } from "react";
import usePOJOState from "./usePOJOState";
/**
 * Hook to use a POJO state which merges values of the previous state with the next one
 * if the partial state update of the next state is not the same as the previous state
 * for the same keys depending on the POJO passed as parameter.
 *
 * The difference from the "usePOJOState" hook is that as soon as the POJO passed as parameter changes
 * (i.e. its reference points to another object), the state is reinitialized.
 *
 * Another difference is that this hook doesn't accept a function returning a POJO as its initial state because
 * it doesn't make sense in this context as the POJO itself is needed to be passed as parameter to this hook
 * in order to determine if it changed since the last rendering.
 *
 * @param {Object} POJO A POJO (Plain Old JavaScript Object).
 * @return {Array} A tuple of two values, current state POJO and callback to set state,
 *                 like the one returned by the "useState" hook.
 *
 *                 The callback to set state may receive an updater function which will receive
 *                 the previous POJO state as argument and must return the next partial POJO state
 *                 update or "null" (to bail out of the state update, read below).
 *
 *                 If the updater function returns "null" or a partial POJO state update which
 *                 has the same values for the same keys as the current POJO state, the update will be
 *                 bailed out as for the "useState" hook.
 */

export default function usePOJOMemoState(POJO) {
  var originalPOJO = POJO;
  var rehidrateStateRef = useRef(false);
  POJO = useMemo(function () {
    rehidrateStateRef.current = true;
    return originalPOJO;
  }, [originalPOJO]);
  var setState;

  var _usePOJOState = usePOJOState(POJO);

  var _usePOJOState2 = _slicedToArray(_usePOJOState, 2);

  POJO = _usePOJOState2[0];
  setState = _usePOJOState2[1];
  useEffect(function () {
    if (rehidrateStateRef.current) {
      rehidrateStateRef.current = false;
      setState(originalPOJO);
    }
  }, [originalPOJO, setState]);
  return [POJO, setState];
}
//# sourceMappingURL=usePOJOMemoState.js.map