function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/*
 * Copyright (c) 2022 Anton Bagdatyev (Tonix)
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
import { useRef, useEffect } from "react";
import { isArray } from "js-utl";
/**
 * Hook to execute a callback each time a component updates
 * (not when it mounts on the initial render).
 *
 * @param {Function} fn The callback to execute.
 * @param {Array|undefined} [deps] Dependencies array to use.
 * @return {undefined}
 */

export default function useUpdateEffect(fn) {
  var deps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : void 0;
  var isInitialRenderRef = useRef(true);

  if (isArray(deps)) {
    // This is needed so that the update effect is triggered on the first update
    // even if the deps array didn't change.
    if (deps.length) {
      if (isInitialRenderRef.current) {
        deps = _toConsumableArray(deps);
        var shouldBreak = false;

        while (true) {
          var rand = Math.random();

          for (var i = 0; i < deps.length; i++) {
            var value = deps[i];

            if (rand !== value) {
              shouldBreak = true;
              break;
            }

            deps[i] = rand + 1;
          }

          if (shouldBreak) {
            break;
          }
        }
      }
    } else {
      if (isInitialRenderRef.current) {
        deps = [0];
      } else {
        deps = [1];
      }
    }
  }

  useEffect(function () {
    if (isInitialRenderRef.current) {
      isInitialRenderRef.current = false;
      return;
    }

    return fn(); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, deps);
}
//# sourceMappingURL=useUpdateEffect.js.map